/*
 * libopensync - A synchronization framework
 * Copyright (C) 2006  NetNix Finland Ltd <netnix@netnix.fi>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 * Author: Daniel Friedrich <daniel.friedrich@opensync.org>
 * 
 */
 
#ifndef OPENSYNCMERGER_INTERNALS_H_
#define OPENSYNCMERGER_INTERNALS_H_

#include <opensync/opensync_xml.h>

#include "opensync_capabilities_internals.h"
#include "opensync_capability_internals.h"
#include "opensync_xmlformat_internals.h"
#include "opensync_xmlfield_internals.h"
#include "opensync_xmlfieldlist_internals.h"
#include "opensync_merger_internals.h"

#endif /*OPENSYNCMERGER_INTERNALS_H_*/
